--[[
	CameraZoomExtension.lua
	
	Autor: 		Ifko[nator]
	Datum: 		27.11.2021
	Version: 	3.0
	
	Changelog:	v1.0 @09.12.2016 - initial implementation in FS 17
				--------------------------------------------------
				v2.0 @01.12.2018 - convert to FS 19
				--------------------------------------------------
				V3.0 @27.11.2021 - convert to FS 22
]]

CameraZoomExtension = {};

CameraZoomExtension.modDirectory = g_currentModDirectory;
CameraZoomExtension.debugPriority = 0;

local function printError(errorMessage, isWarning, isInfo)
	local prefix = "::ERROR:: ";
	
	if isWarning then
		prefix = "::WARNING:: ";
	elseif isInfo then
		prefix = "::INFO:: ";
	end;
	
	print(prefix .. "from the CameraZoomExtension.lua: " .. tostring(errorMessage));
end;

local function printDebug(debugMessage, priority, addString)
	if CameraZoomExtension.debugPriority >= priority then
		local prefix = "";
		
		if addString then
			prefix = "::DEBUG:: from the CameraZoomExtension.lua: ";
		end;
		
		print(prefix .. tostring(debugMessage));
	end;
end;

function CameraZoomExtension.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(Drivable, specializations);
end;

function CameraZoomExtension.registerEventListeners(vehicleType)
	local functionNames = {
		"onLoad"
	};
	
	for _, functionName in ipairs(functionNames) do
		SpecializationUtil.registerEventListener(vehicleType, functionName, CameraZoomExtension);
	end;
end;

function CameraZoomExtension:onLoad(savegame)
	local modDesc = loadXMLFile("modDesc", CameraZoomExtension.modDirectory .. "modDesc.xml");
	local specEnterable = self.spec_enterable;
	
	specEnterable.camZoomMax = Utils.getNoNil(getXMLFloat(modDesc, "modDesc.vehicleCam#transMax"), 60);
	CameraZoomExtension.debugPriority = Utils.getNoNil(getXMLFloat(modDesc, "modDesc.vehicleCam#debugPriority"), CameraZoomExtension.debugPriority);
	
	specEnterable.camZoomMax = math.floor(specEnterable.camZoomMax);
	
	if specEnterable.cameras ~= nil then
		for cameraNumber, camera in pairs(specEnterable.cameras) do
			if camera.transMax ~= nil then
				if camera.transMax > 0 then
					printDebug("Found 'transMax'! Value = '" .. camera.transMax .."' in cam: '" .. cameraNumber .. "'.", 1, true);
			
					if camera.transMax < specEnterable.camZoomMax then
						camera.transMax = specEnterable.camZoomMax;
						
						printDebug("Set 'transMax' for cam '" .. cameraNumber .. "' to: '" .. camera.transMax .. "'.", 1, true);
					end;
				end;
			end;
		end;
	else
		printError("Can't find cameras in '" .. self.configFileName .. "'! Script is Stopped for this Vehicle!", false, false);
	end;
	
	delete(modDesc);
end;